manytomanydelegate — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- delegates »

# manytomanydelegate

class `camelot.view.controls.delegates.manytomanydelegate.` `ManyToManyDelegate`(parent=None, **kwargs)

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- delegates »

Comments
blog comments powered by Disqus